package com.muyu.controller;

import com.alibaba.fastjson.JSONObject;
import com.muyu.common.Common;
import com.muyu.common.Config;
import com.muyu.common.Response;
import com.muyu.netty.log.NettyClientLogQueue;
import com.muyu.netty.operate.NettyClientMsg;
import com.muyu.pojo.VehicleData;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.concurrent.LinkedBlockingQueue;

/**
 * @author 牧鱼
 * @Classname VehicleDataController
 * @Description 车辆模拟数据
 * @Date 2021/11/8 8:24
 */
@RestController
@RequestMapping("/vehicle/operate")
public class VehicleOperateController {

    /**
     * 日志
     * */
    private final Logger log = LoggerFactory.getLogger(VehicleOperateController.class);

    /**
     * 路径队列
     */
    private final LinkedBlockingQueue<String> locusQueue = new LinkedBlockingQueue<>();

    /**
     * 车辆启动报文
     * @param vin
     * @return
     */
    @GetMapping("/start/{vin}")
    public Response sendVehicleStart(@PathVariable(value = "vin") String vin){
        if (Config.ctx == null){
            return Response.error("未与netty服务器建立连接");
        }
        NettyClientMsg.sendMsg(Config.VEHICLE_START_SUF + vin);
        NettyClientLogQueue.add("<p>VIN:"+vin+" ， 发送启动报文</p>");
        return Response.success();
    }

    /**
     * 通过VIN选择路线
     * @param vin
     * @param imitatePositionId
     * @return
     */
    @GetMapping("/selectLocus/{vin}/{imitatePositionId}")
    public Response selectLocus(@PathVariable(value = "vin") String vin,
                                @PathVariable(value = "imitatePositionId") String imitatePositionId){
        //从数据库当中取出数据
        String positionStr = Common.localMap.get(imitatePositionId);
        List<String> positionStrList = JSONObject.parseArray(positionStr, String.class);
        locusQueue.addAll(positionStrList);
        log.info("VIN：{} 选择车辆轨迹：{}",vin,imitatePositionId);
        return Response.success();
    }


    /**
     * 发送消息
     * @param vehicleData
     * @return
     */
    @PostMapping("/sendMsg")
    public Response sendMsg(@RequestBody VehicleData vehicleData){
        if (Config.ctx == null){
            return Response.error("未与netty服务器建立连接");
        }
        String s =locusQueue.poll();
        if (s == null){
            return Response.error("预定路线已经行驶完毕！");
        }

        String[] split = s.split(",");
        vehicleData.setLongitude(split[0]);
        vehicleData.setLatitude(split[1]);

        NettyClientMsg.sendMsg(Config.VEHICLE_MSG_SUF + vehicleData.getVin() +JSONObject.toJSONString(vehicleData));
        NettyClientLogQueue.add(vehicleData.getVehicleMsgLog());
        return Response.success();
    }


    /**
     * 车辆关闭报文
     * @param vin
     * @return
     */
    @GetMapping("/stop/{vin}")
    public Response sendVehicleStop(@PathVariable(value = "vin") String vin){
        if (Config.ctx == null){
            return Response.error("未与netty服务器建立连接");
        }
        NettyClientMsg.sendMsg(Config.VEHICLE_STOP_SUF + vin);
        NettyClientLogQueue.add("<p>VIN:"+vin+" ， 发送关闭报文</p>");
        return Response.success();
    }
}
