package com.muyu.netty.client;

import com.muyu.common.Config;
import com.muyu.netty.log.NettyClientLogQueue;
import com.muyu.netty.operate.NettyClientMsg;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelInboundHandlerAdapter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class NettyClientHandler extends ChannelInboundHandlerAdapter {

	private static final Logger log = LoggerFactory.getLogger(NettyClientHandler.class);

	/**
	 * 隧道连接后首次调用
	 * @param ctx
	 * @throws Exception
	 */
	@Override
	public void channelActive(ChannelHandlerContext ctx) throws Exception {
		log.info("客户端与服务器建立连接成功");
		Config.ctx = ctx;
	}

	/**
	 * 隧道读取数据
	 * @param ctx
	 * @param msg
	 * @throws Exception
	 */
	@Override
	public void channelRead(ChannelHandlerContext ctx, Object msg) throws Exception {
		log.info("接收消息:" + msg);
		NettyClientLogQueue.add("<p>接收到服务端发来的消息"+msg+"</p>");
		switch (msg.toString()){
			//服务器首次建立连接 发送CONNECT
			case Config.NETTY_CONNECT:
				NettyClientMsg.sendMsg(Config.START_VIN_SUF +Config.VIN);
				break;
			//服务器接收到VIN SUCCESS_VIN
			case Config.START_VIN_SUCCESS_SUF:
				NettyClientMsg.sendMsg(Config.START_VIN_SUCCESS_SUF +Config.VIN);
				Config.IS_CONNECT = true;
				break;
			//服务器响应退出
			case Config.NETTY_CLOSE:
				ctx.writeAndFlush(Config.NETTY_CLOSE).addListener(ChannelFutureListener.CLOSE);
			break;
		}

		if ("断开".equals(msg)){
			ctx.writeAndFlush("客户端退出").addListener(ChannelFutureListener.CLOSE);
		}

	}

	/**
	 * 隧道发生异常后捕捉异常
	 * @param ctx
	 * @param cause
	 * @throws Exception
	 */
	@Override
	public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) throws Exception {
		log.info("客户端捕获异常：{}",cause.getMessage());
		cause.printStackTrace();
	}

	/**
	 * 隧道断开之后调用方法
	 * @param ctx
	 * @throws Exception
	 */
	@Override
	public void channelInactive(ChannelHandlerContext ctx) throws Exception {
		log.info("隧道切换不活跃状态");
		Config.ctx = null;
	}


}
